@@ -343,10 +343,10 @@ static int extract_paths_to_stream(struct archive *a, FILE * stream)
         path = archive_entry_pathname(entry);
         entry_stat = archive_entry_stat(entry);
         if (S_ISLNK(entry_stat->st_mode)) {
-            r = fprintf(stream, "%s\t0%03o\t%s\n", path, (unsigned int)entry_stat->st_mode,
+            r = fprintf(stream, "%s\t%#03o\t%s\n", path, (unsigned int)entry_stat->st_mode,
                         archive_entry_symlink(entry));
         } else {
-            r = fprintf(stream, "%s\t0%03o\n", path, (unsigned int)entry_stat->st_mode);
+            r = fprintf(stream, "%s\t%#03o\n", path, (unsigned int)entry_stat->st_mode);
         }
         if (r <= 0) {
             opkg_msg(ERROR, "Failed to path to stream: %s\n", strerror(errno));
@@ -596,6 +596,19 @@ static struct archive *open_inner(struct archive *outer)
     }
 #endif
 
+#if HAVE_LZ4
+    r = archive_read_support_filter_lz4(inner);
+    if (r == ARCHIVE_WARN) {
+        /* libarchive returns ARCHIVE_WARN if the filter is provided by
+         * an external program.
+         */
+        opkg_msg(INFO, "Lz4 support provided by external program.\n");
+    } else if (r != ARCHIVE_OK) {
+        opkg_msg(ERROR, "Lz4 format not supported.\n");
+        goto err_cleanup;
+    }
+#endif
+
     r = archive_read_support_format_tar(inner);
     if (r != ARCHIVE_OK) {
         opkg_msg(ERROR, "Tar format not supported: %s\n",
@@ -804,6 +817,11 @@ struct opkg_ar *ar_open_pkg_control_archive(const char *filename)
     if (!ar->ar) {
         ar->ar = extract_outer(filename, "control.tar.bz2");
     }
+#endif
+#if HAVE_LZ4
+    if (!ar->ar) {
+        ar->ar = extract_outer(filename, "control.tar.lz4");
+    }
 #endif
     if (!ar->ar) {
         free(ar);
@@ -836,6 +854,11 @@ struct opkg_ar *ar_open_pkg_data_archive(const char *filename)
     if (!ar->ar) {
         ar->ar = extract_outer(filename, "data.tar.bz2");
     }
+#endif
+#if HAVE_LZ4
+    if (!ar->ar) {
+        ar->ar = extract_outer(filename, "data.tar.lz4");
+    }
 #endif
     if (!ar->ar) {
         free(ar);
