@@ -484,6 +484,7 @@ static void pkg2solvable(pkg_t *pkg, Solvable *solvable_out)
 static void populate_installed_repo(libsolv_solver_t *libsolv_solver)
 {
     int i;
+    Id what;
 
     pkg_vec_t *installed_pkgs = pkg_vec_alloc();
 
@@ -507,6 +508,15 @@ static void populate_installed_repo(libsolv_solver_t *libsolv_solver)
         /* set solvable attributes */
         pkg2solvable(pkg, solvable);
 
+        /* if the package is in ignore-recommends-list, disfavor installation */
+        if (str_list_contains(&opkg_config->ignore_recommends_list, pkg->name)) {
+            opkg_message(NOTICE, "Disfavor package: %s\n",
+                         pkg->name);
+            what = pool_str2id(libsolv_solver->pool, pkg->name, 1);
+            queue_push2(&libsolv_solver->solver_jobs, SOLVER_SOLVABLE_NAME
+                        | SOLVER_DISFAVOR, what);
+        }
+
         /* if the package is not autoinstalled, mark it as user installed */
         if (!pkg->auto_installed)
             queue_push2(&libsolv_solver->solver_jobs, SOLVER_SOLVABLE
@@ -539,7 +549,7 @@ static void populate_available_repos(libsolv_solver_t *libsolv_solver)
 {
     int i;
     Solvable *solvable;
-    Id solvable_id;
+    Id solvable_id, what;
 
     pkg_vec_t *available_pkgs = pkg_vec_alloc();
 
@@ -608,6 +618,15 @@ static void populate_available_repos(libsolv_solver_t *libsolv_solver)
         solvable = pool_id2solvable(libsolv_solver->pool, solvable_id);
         pkg2solvable(pkg, solvable);
 
+        /* if the package is in ignore-recommends-list, disfavor installation */
+        if (str_list_contains(&opkg_config->ignore_recommends_list, pkg->name)) {
+            opkg_message(NOTICE, "Disfavor package: %s\n",
+                         pkg->name);
+            what = pool_str2id(libsolv_solver->pool, pkg->name, 1);
+            queue_push2(&libsolv_solver->solver_jobs, SOLVER_SOLVABLE_NAME
+                        | SOLVER_DISFAVOR, what);
+        }
+
         /* if the --force-depends option is specified make dependencies weak */
         if (opkg_config->force_depends)
             queue_push2(&libsolv_solver->solver_jobs, SOLVER_SOLVABLE
@@ -672,6 +691,10 @@ static int libsolv_solver_init(libsolv_solver_t *libsolv_solver)
     /* create the solver with the solver pool */
     libsolv_solver->solver = solver_create(libsolv_solver->pool);
 
+    /* allow upgrades of installed packages during install */
+    solver_set_flag(libsolv_solver->solver,
+                    SOLVER_FLAG_INSTALL_ALSO_UPDATES, 1);
+
     /* set libsolv solver flags to match behavoir of opkg options */
     if (opkg_config->force_removal_of_dependent_packages)
         solver_set_flag(libsolv_solver->solver,
@@ -685,8 +708,6 @@ static int libsolv_solver_init(libsolv_solver_t *libsolv_solver)
     } else {
          solver_set_flag(libsolv_solver->solver,
                         SOLVER_FLAG_STRONG_RECOMMENDS, 1);
-         solver_set_flag(libsolv_solver->solver,
-                        SOLVER_FLAG_INSTALL_ALSO_UPDATES, 1);
     }
     if (!opkg_config->prefer_arch_to_version) {
         solver_set_flag(libsolv_solver->solver,
@@ -876,8 +897,10 @@ static int libsolv_solver_execute_transaction(libsolv_solver_t *libsolv_solver)
     } else {
         pkg_t *pkg;
 
-        if (libsolv_solver_transaction_preamble(libsolv_solver, pkgs, transaction, 0))
+        if (libsolv_solver_transaction_preamble(libsolv_solver, pkgs, transaction, 0)) {
+            err = -1;
             goto CLEANUP;
+        }
 
         for (i = 0; i < transaction->steps.count; i++) {
             Id stepId = transaction->steps.elements[i];
